@@ -19,4 +19,9 @@ MAXPAGESIZE=0x80
 DATA_ADDR="ALIGN(${MAXPAGESIZE})"
 OTHER_BSS_SECTIONS=".toe ALIGN(128) : { *(.toe) } = 0"
 OTHER_SECTIONS=".note.spu_name 0 : { KEEP(*(.note.spu_name)) }
-  ._ea 0 : { KEEP(*(._ea)) KEEP(*(._ea.*)) }"
+  ._ea 0 : { KEEP(*(._ea))${RELOCATING+ KEEP(*(._ea.*))} }"
+OTHER_READONLY_SECTIONS="
+  .fixup ${RELOCATING-0} : {
+    ${RELOCATING+PROVIDE (__fixup_start = .);}
+    KEEP(*(.fixup))
+  }"
