@@ -7,5 +7,5 @@ ARCH=sh
 MACHINE=
 TEMPLATE_NAME=elf32
 GENERATE_SHLIB_SCRIPT=yes
-TEXT_START_SYMBOLS='_btext = .;'
+TEXT_START_SYMBOLS="${CREATE_SHLIB+PROVIDE (}_btext = .${CREATE_SHLIB+)};"
 ENTRY=_start
