@@ -1,5 +1,5 @@
 /* Plugin control for the GNU linker.
-   Copyright (C) 2010-2014 Free Software Foundation, Inc.
+   Copyright (C) 2010-2019 Free Software Foundation, Inc.
 
    This file is part of the GNU Binutils.
 
@@ -39,10 +39,6 @@ extern void plugin_opt_plugin (const char *plugin);
    error if none.  */
 extern int plugin_opt_plugin_arg (const char *arg);
 
-/* Return true if any plugins are active this run.  Only valid
-   after options have been processed.  */
-extern bfd_boolean plugin_active_plugins_p (void);
-
 /* Load up and initialise all plugins after argument parsing.  */
 extern void plugin_load_plugins (void);
 
@@ -50,8 +46,7 @@ extern void plugin_load_plugins (void);
 extern const char *plugin_error_plugin (void);
 
 /* Call 'claim file' hook for all plugins.  */
-extern void plugin_maybe_claim (struct ld_plugin_input_file *,
-				lang_input_statement_type *);
+extern void plugin_maybe_claim (lang_input_statement_type *);
 
 /* Call 'all symbols read' hook for all plugins.  */
 extern int plugin_call_all_symbols_read (void);
@@ -59,14 +54,4 @@ extern int plugin_call_all_symbols_read (void);
 /* Call 'cleanup' hook for all plugins at exit.  */
 extern void plugin_call_cleanup (void);
 
-/* Generate a dummy BFD to represent an IR file, for any callers of
-   plugin_call_claim_file to use as the handle in the ld_plugin_input_file
-   struct that they build to pass in.  The BFD is initially writable, so
-   that symbols can be added to it; it must be made readable after the
-   add_symbols hook has been called so that it can be read when linking.  */
-extern bfd *plugin_get_ir_dummy_bfd (const char *name, bfd *template);
-
-/* Return true if bfd is a dynamic library that should be reloaded.  */
-extern bfd_boolean plugin_should_reload (bfd *);
-
 #endif /* !def GLD_PLUGIN_H */
